FlutterWebVibrate class

Constructors

FlutterWebVibrate()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

injectJavaScript() → void
Injects the JavaScript vibration code into the HTML page.
isVibrationSupported() bool
Checks if the device supports the Vibration API.
vibrate(int duration) → void
Vibrates the device for the given duration in milliseconds. Only works if the browser supports the Vibration API.